@@ -2,7 +2,7 @@
  * (c)LGPL2+
  *
  * LXQt - a lightweight, Qt based, desktop toolset
- * http://razor-qt.org
+ * https://lxqt.org
  *
  * Copyright: 2012 Razor team
  * Authors:
@@ -87,8 +87,8 @@ LXQtThemeConfig::LXQtThemeConfig(LXQt::Settings *settings, QWidget *parent) :
     });
 
 
-    QList<LXQt::LXQtTheme> themes = LXQt::LXQtTheme::allThemes();
-    foreach(LXQt::LXQtTheme theme, themes)
+    const QList<LXQt::LXQtTheme> themes = LXQt::LXQtTheme::allThemes();
+    for(const LXQt::LXQtTheme &theme : themes)
     {
         QString themeName = theme.name();
         themeName[0] = themeName[0].toTitleCase();
