@@ -2,7 +2,7 @@
  * (c)LGPL2+
  *
  * LXQt - a lightweight, Qt based, desktop toolset
- * http://lxde.org/
+ * https://lxqt.org/
  *
  * Copyright: 2014 LXQt team
  * Authors:
@@ -52,7 +52,8 @@ StyleConfig::StyleConfig(LXQt::Settings* settings, QSettings* qtSettings, QWidge
     connect(ui->styleList, SIGNAL(itemClicked(QTreeWidgetItem*,int)),
             this, SLOT(styleSelected(QTreeWidgetItem*,int)));
 
-    Q_FOREACH(const QString& name, QStyleFactory::keys())
+    const auto keys = QStyleFactory::keys();
+    for(const QString& name : keys)
     {
         QTreeWidgetItem *item = new QTreeWidgetItem(QStringList(name));
         ui->styleList->addTopLevelItem(item);
