@@ -2,7 +2,7 @@
  * (c)LGPL2+
  *
  * LXQt - a lightweight, Qt based, desktop toolset
- * http://razor-qt.org
+ * https://lxqt.org
  *
  * Copyright: 2010-2011 Razor team
  * Authors:
@@ -35,7 +35,7 @@
 
 class QCategorizedSortFilterProxyModel;
 
-namespace LxQtConfig {
+namespace LXQtConfig {
 
     class ConfigPaneModel;
 
@@ -50,17 +50,22 @@ class MainWindow : public QMainWindow, public Ui::MainWindow
 public:
     MainWindow();
 
+protected:
+    virtual bool event(QEvent * event) override;
+    virtual bool eventFilter(QObject * watched, QEvent * event) override;
+
 private:
     QCategorizedSortFilterProxyModel *proxyModel;
     ConfigPaneModel *model;
+    QPersistentModelIndex pendingActivation;
 
 private:
     void builGroup(const QDomElement& xml);
-    bool event(QEvent *event);
+    void setSizing();
+    void activateItem();
 
 private slots:
     void load();
-    void activateItem(const QModelIndex &index);
 };
 
 }; // namespace
