@@ -330,7 +330,7 @@ void QCategorizedView::Private::rowsInserted(const QModelIndex &parent, int star
         QList<Block> blockList = blocks.values();
         qSort(blockList.begin(), blockList.end(), Block::lessThan);
         QList<int> firstIndexesRows;
-        foreach (const Block &block, blockList) {
+        for (const Block &block : qAsConst(blockList)) {
             firstIndexesRows << block.firstIndex.row();
         }
         //END: order for marking as alternate those blocks that are alternate
@@ -1328,7 +1328,7 @@ void QCategorizedView::rowsAboutToBeRemoved(const QModelIndex &parent,
     }
     //END: update the items that are in quarantine in affected categories
 
-    Q_FOREACH (const QString &category, listOfCategoriesMarkedForRemoval) {
+    for(const QString &category : qAsConst(listOfCategoriesMarkedForRemoval)) {
         d->blocks.remove(category);
     }
 
@@ -1338,7 +1338,7 @@ void QCategorizedView::rowsAboutToBeRemoved(const QModelIndex &parent,
         QList<Private::Block> blockList = d->blocks.values();
         qSort(blockList.begin(), blockList.end(), Private::Block::lessThan);
         QList<int> firstIndexesRows;
-        foreach (const Private::Block &block, blockList) {
+        for (const Private::Block &block : qAsConst(blockList)) {
             firstIndexesRows << block.firstIndex.row();
         }
         //END: order for marking as alternate those blocks that are alternate
